CircularlyShapedCompartment: Circularly-shaped compartment class

CircularlyShapedCompartmentR Documentation

Circularly-shaped compartment class

Description

A class to model restricted diffusion in a bounded medium described by a circular shape with a given radius.

Super class

BaseCompartment -> CircularlyShapedCompartment

Methods

Public methods

Inherited methods

CircularlyShapedCompartment$new()

Instantiates a new circular compartment.

Usage
CircularlyShapedCompartment$new(radius = NULL, diffusivity = NULL)
Arguments
radius

A numeric value specifying the radius of the sphere in \mum.

diffusivity

A numeric value specifying the diffusivity within the sphere in \mum^2.ms^{-1}.

Returns

An instance of the CircularlyShapedCompartment class.


CircularlyShapedCompartment$clone()

The objects of this class are cloneable with this method.

Usage
CircularlyShapedCompartment$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


midi documentation built on July 6, 2026, 1:08 a.m.