| CylinderBundleCompartment | R Documentation |
A class to model restricted diffusion in a bundle of cylinders.
BaseCompartment -> CylinderBundleCompartment
CylinderBundleCompartment$new()Instantiates a new cylinder bundle compartment.
CylinderBundleCompartment$new( cylinder_density, cylinder_compartments, axial_diffusivity = NULL, radial_diffusivity = NULL )
cylinder_densityA numeric value specifying the density of the cylinders in the voxel. Must be between 0 and 1.
cylinder_compartmentsA list of instances of the
CylinderCompartment class specifying the compartments within the
bundle.
axial_diffusivityA numeric value specifying the axial diffusivity
in the space outside the cylinders in m^2.s^{-1}. If not
provided, defaults to a tortuosity model reducing the intrinsic
diffusivity depending on orientation dispersion. Defaults to NULL in
which case the extracellular axial diffusivity is set via a tortuosity
model based on the dispersion in orientation.
radial_diffusivityA numeric value specifying the radial
diffusivity in the space outside the cylinders in
m^2.s^{-1}. Defaults to NULL in which case the
extracellular radial diffusivity is set via a tortuosity model based on
the intracellular density.
An instance of the CylinderBundleCompartment class.
CylinderBundleCompartment$clone()The objects of this class are cloneable with this method.
CylinderBundleCompartment$clone(deep = FALSE)
deepWhether to make a deep clone.
withr::with_seed(1234, {
cyls <- rcylinders(
n = 100,
axis_mean = c(0, 0, 1),
radius_mean = 5,
diffusivity_mean = 3,
axis_concentration = 10,
radius_sd = 1,
diffusivity_sd = 0
)
})
comp <- CylinderBundleCompartment$new(
cylinder_density = 0.5,
cylinder_compartments = cyls
)
comp$get_signal(
small_delta = 30,
big_delta = 30,
G = 0.040,
direction = c(0, 0, 1)
)
comp$get_parameters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.