FreeCompartment: Free compartment class

FreeCompartmentR Documentation

Free compartment class

Description

A class to model free unconstrained diffusion.

Super class

BaseCompartment -> FreeCompartment

Methods

Public methods

Inherited methods

FreeCompartment$new()

Instantiates a new free compartment.

Usage
FreeCompartment$new(diffusivity = NULL)
Arguments
diffusivity

A numeric value specifying the diffusivity within the sphere in \mum^2.ms^{-1}. Defaults to NULL, in which case the default free diffusivity of 3 \mum^2.ms^{-1} is used.

Returns

An instance of the FreeCompartment class.


FreeCompartment$clone()

The objects of this class are cloneable with this method.

Usage
FreeCompartment$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


midi documentation built on July 6, 2026, 1:08 a.m.