NeumanCompartment: Neuman's model for restricted diffusion in a cylinder

NeumanCompartmentR Documentation

Neuman's model for restricted diffusion in a cylinder

Description

A class to model restricted diffusion in a cylinder using the Neuman's model.

Super classes

BaseCompartment -> CircularlyShapedCompartment -> NeumanCompartment

Methods

Public methods

Inherited methods

NeumanCompartment$clone()

The objects of this class are cloneable with this method.

Usage
NeumanCompartment$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Neuman, C. H. (1974). Spin echo of spins diffusing in a bounded medium. The Journal of Chemical Physics, 60(11), 4508-4511.


midi documentation built on July 6, 2026, 1:08 a.m.