SphereCompartment: Sphere compartment class

SphereCompartmentR Documentation

Sphere compartment class

Description

A class to model restricted diffusion in a sphere.

Super classes

BaseCompartment -> CircularlyShapedCompartment -> SphereCompartment

Methods

Public methods

Inherited methods

SphereCompartment$new()

Instantiates a new sphere compartment.

Usage
SphereCompartment$new(restricted_compartment = VanGelderenCompartment$new())
Arguments
restricted_compartment

An instance of the CircularlyShapedCompartment class specifying the restricted compartment within the sphere. Defaults to a Van Gelderen compartment.

Returns

An instance of the SphereCompartment class.


SphereCompartment$clone()

The objects of this class are cloneable with this method.

Usage
SphereCompartment$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

sphComp <- SphereCompartment$new()
sphComp$get_signal(small_delta = 30, big_delta = 30, G = 0.040)
sphComp$get_parameter_names()
sphComp$get_parameters()

midi documentation built on July 6, 2026, 1:08 a.m.