Learn R Programming

midi (version 0.1.0)

VanGelderenCompartment: Van Gelderen's model for restricted diffusion in a cylinder

Description

A class to model restricted diffusion in a cylinder using the Van Gelderen's model.

Arguments

Super class

midi::CylinderRadialCompartment -> VanGelderenCompartment

Methods

Inherited methods


Method clone()

The objects of this class are cloneable with this method.

Usage

VanGelderenCompartment$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Vangelderen, P., DesPres, D., Vanzijl, P. C. M., & Moonen, C. T. W. (1994). Evaluation of restricted diffusion in cylinders. Phosphocreatine in rabbit leg muscle. Journal of Magnetic Resonance, Series B, 103(3), 255-260.