WatsonDistribution: Watson distribution class

WatsonDistributionR Documentation

Watson distribution class

Description

This class defines the Watson distribution. It provides methods for fitting the distribution to data and generating random samples.

Super class

BaseDistribution -> WatsonDistribution

Methods

Public methods

Inherited methods

WatsonDistribution$new()

Creates a new Watson distribution.

Usage
WatsonDistribution$new(mu = c(0, 0, 1), kappa = 10)
Arguments
mu

A numeric vector of length 3 specifying the mean direction of the Watson distribution. Defaults to ⁠(0, 0, 1)⁠.

kappa

A numeric value specifying the concentration parameter of the Watson distribution. Defaults to 10.0.

Returns

An instance of the Watson distribution as an object of class WatsonDistribution.


WatsonDistribution$get_axis()

Retrieves the mean axis of the Watson distribution.

Usage
WatsonDistribution$get_axis()
Returns

A numeric vector of length 3 storing the mean axis of the Watson distribution.


WatsonDistribution$get_concentration()

Retrieves the concentration parameter of the Watson distribution.

Usage
WatsonDistribution$get_concentration()
Returns

A numeric value storing the concentration parameter of the Watson distribution.


WatsonDistribution$clone()

The objects of this class are cloneable with this method.

Usage
WatsonDistribution$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Examples

wd <- WatsonDistribution$new(
  mu = c(0, 0, 1),
  kappa = 10
)
wd$get_axis()
wd$get_concentration()
wd$random(10)
wd$fit(wd$random(100))
wd$get_axis()
wd$get_concentration()

midi documentation built on July 6, 2026, 1:08 a.m.