bvalue: B-Value Calculation

View source: R/utils.R

bvalueR Documentation

B-Value Calculation

Description

A function to calculate the b-value for a given set of experimental parameters.

Usage

bvalue(small_delta, big_delta, G)

Arguments

small_delta

A numeric value specifying the duration of the gradient pulse in ms.

big_delta

A numeric value specifying the duration between the gradient pulses in ms.

G

A numeric value specifying the strength of the gradient in \muT/\mum.

Value

A numeric value storing the predicted b-value in ms/\mum^2.

Examples

bvalue(small_delta = 30, big_delta = 30, G = 0.040)

midi documentation built on July 6, 2026, 1:08 a.m.