| BaseDistribution | R Documentation |
This class defines the base distribution class from which all other distributions inherit. It provides a common interface for fitting the distribution to data and generating random samples.
BaseDistribution$fit()Fit the distribution to the data.
BaseDistribution$fit(x)
xA numeric vector of data to fit the distribution to.
Internally sets the parameters of the distribution. Returns nothing.
BaseDistribution$random()Generate random samples from the distribution.
BaseDistribution$random(n)
nAn integer specifying the number of samples to generate.
A numeric vector of size n containing the random samples.
BaseDistribution$get_mean()Compute the mean of the distribution.
BaseDistribution$get_mean()
A numeric value storing the mean of the distribution.
BaseDistribution$get_variance()Compute the variance of the distribution.
BaseDistribution$get_variance()
A numeric value storing the variance of the distribution.
BaseDistribution$clone()The objects of this class are cloneable with this method.
BaseDistribution$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.