| CircularlyShapedCompartment | R Documentation |
A class to model restricted diffusion in a bounded medium described by a circular shape with a given radius.
BaseCompartment -> CircularlyShapedCompartment
CircularlyShapedCompartment$new()Instantiates a new circular compartment.
CircularlyShapedCompartment$new(radius = NULL, diffusivity = NULL)
radiusA numeric value specifying the radius of the sphere in
\mum.
diffusivityA numeric value specifying the diffusivity within the
sphere in \mum^2.ms^{-1}.
An instance of the CircularlyShapedCompartment class.
CircularlyShapedCompartment$clone()The objects of this class are cloneable with this method.
CircularlyShapedCompartment$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.