| CylinderCompartment | R Documentation |
A class to model restricted diffusion in a cylinder.
BaseCompartment -> CircularlyShapedCompartment -> CylinderCompartment
CylinderCompartment$new()Instantiates a new cylinder compartment.
CylinderCompartment$new( axis = c(0, 0, 1), restricted_compartment = VanGelderenCompartment$new() )
axisA length-3 numeric vector specifying the axis of the cylinder.
restricted_compartmentAn instance of the
CircularlyShapedCompartment class specifying the restricted
compartment within the sphere. Defaults to a Van Gelderen compartment.
An instance of the CylinderCompartment class.
CylinderCompartment$clone()The objects of this class are cloneable with this method.
CylinderCompartment$clone(deep = FALSE)
deepWhether to make a deep clone.
cylComp <- CylinderCompartment$new()
cylComp$get_signal(small_delta = 30, big_delta = 30, G = 0.040)
cylComp$get_parameter_names()
cylComp$get_parameters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.