| GammaDistribution | R Documentation |
This class defines the gamma distribution. It provides methods for fitting the distribution to data and generating random samples.
BaseDistribution -> GammaDistribution
GammaDistribution$new()Creates a new gamma distribution.
GammaDistribution$new(shape = 1, scale = 1)
shapeA numeric value specifying the shape parameter of the gamma
distribution. Defaults to 1.0.
scaleA numeric value specifying the scale parameter of the gamma
distribution. Defaults to 1.0.
An instance of the gamma distribution as an object of class
GammaDistribution.
GammaDistribution$get_shape()Retrieves the shape parameter of the gamma distribution.
GammaDistribution$get_shape()
A numeric value storing the shape parameter of the gamma distribution.
GammaDistribution$get_scale()Retrieves the scale parameter of the gamma distribution.
GammaDistribution$get_scale()
A numeric value storing the scale parameter of the gamma distribution.
GammaDistribution$clone()The objects of this class are cloneable with this method.
GammaDistribution$clone(deep = FALSE)
deepWhether to make a deep clone.
gd <- GammaDistribution$new(
shape = 1,
scale = 5
)
gd$get_shape()
gd$get_scale()
gd$get_mean()
gd$get_variance()
gd$random(10)
gd$fit(gd$random(100))
gd$get_shape()
gd$get_scale()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.