| SphereCompartment | R Documentation |
A class to model restricted diffusion in a sphere.
BaseCompartment -> CircularlyShapedCompartment -> SphereCompartment
SphereCompartment$new()Instantiates a new sphere compartment.
SphereCompartment$new(restricted_compartment = VanGelderenCompartment$new())
restricted_compartmentAn instance of the
CircularlyShapedCompartment class specifying the restricted
compartment within the sphere. Defaults to a Van Gelderen compartment.
An instance of the SphereCompartment class.
SphereCompartment$clone()The objects of this class are cloneable with this method.
SphereCompartment$clone(deep = FALSE)
deepWhether to make a deep clone.
sphComp <- SphereCompartment$new()
sphComp$get_signal(small_delta = 30, big_delta = 30, G = 0.040)
sphComp$get_parameter_names()
sphComp$get_parameters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.