| WatsonDistribution | R Documentation |
This class defines the Watson distribution. It provides methods for fitting the distribution to data and generating random samples.
BaseDistribution -> WatsonDistribution
WatsonDistribution$new()Creates a new Watson distribution.
WatsonDistribution$new(mu = c(0, 0, 1), kappa = 10)
muA numeric vector of length 3 specifying the mean direction of
the Watson distribution. Defaults to (0, 0, 1).
kappaA numeric value specifying the concentration parameter of
the Watson distribution. Defaults to 10.0.
An instance of the Watson distribution as an object of class
WatsonDistribution.
WatsonDistribution$get_axis()Retrieves the mean axis of the Watson distribution.
WatsonDistribution$get_axis()
A numeric vector of length 3 storing the mean axis of the Watson distribution.
WatsonDistribution$get_concentration()Retrieves the concentration parameter of the Watson distribution.
WatsonDistribution$get_concentration()
A numeric value storing the concentration parameter of the Watson distribution.
WatsonDistribution$clone()The objects of this class are cloneable with this method.
WatsonDistribution$clone(deep = FALSE)
deepWhether to make a deep clone.
wd <- WatsonDistribution$new(
mu = c(0, 0, 1),
kappa = 10
)
wd$get_axis()
wd$get_concentration()
wd$random(10)
wd$fit(wd$random(100))
wd$get_axis()
wd$get_concentration()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.