| bvalue | R Documentation |
A function to calculate the b-value for a given set of experimental parameters.
bvalue(small_delta, big_delta, G)
small_delta |
A numeric value specifying the duration of the gradient pulse in ms. |
big_delta |
A numeric value specifying the duration between the gradient pulses in ms. |
G |
A numeric value specifying the strength of the gradient in
|
A numeric value storing the predicted b-value in
ms/\mum^2.
bvalue(small_delta = 30, big_delta = 30, G = 0.040)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.